@@ -91,6 +91,7 @@ setMethod(
     slot(.Object, "mlg")      <- mlg
     slot(.Object, "visible")  <- "original"
     slot(.Object, "distname") <- "diss.dist"
+    slot(.Object, "distenv")  <- .GlobalEnv
     slot(.Object, "distargs") <- list()
     slot(.Object, "distalgo") <- "farthest_neighbor"
     return(.Object)
@@ -444,6 +445,22 @@ setMethod(
     x@distname
   })
 
+#==============================================================================#
+#' @rdname MLG-accessors
+#' @aliases distenv,MLG-method
+#' @export
+#==============================================================================#
+setGeneric("distenv", function(x) {
+  standardGeneric("distenv")
+})
+
+setMethod(
+  f = "distenv", 
+  signature(x = "MLG"), 
+  definition = function(x) {
+    x@distenv
+  })
+
 #==============================================================================#
 #' @rdname MLG-accessors
 #' @aliases distname<-,MLG-method
@@ -461,6 +478,23 @@ setMethod(
     return(x)
   })
 
+#==============================================================================#
+#' @rdname MLG-accessors
+#' @aliases distenv<-,MLG-method
+#' @export
+#==============================================================================#
+setGeneric("distenv<-", function(x, value) {
+  standardGeneric("distenv<-")
+})
+
+setMethod(
+  f = "distenv<-", 
+  signature(x = "MLG"), 
+  definition = function(x, value) {
+    x@distenv <- value
+    return(x)
+  })
+
 #==============================================================================#
 #' @rdname MLG-accessors
 #' @aliases distargs,MLG-method
@@ -560,4 +594,4 @@ setMethod(
   definition = function(x, value) {
     x@cutoff <- value
     return(x)
-  })
\ No newline at end of file
+  })
